# Overview
IncantoOS was developed to make tasks smaller.

# Usage
IncantoOS Wasnt intended for other people to use it use at your own caution

# Notes
I will try to keep up with the documentation of IncantoOS even though it wasnt meant for public use.

# Discresion
I am not the best coder so do not expect IncantoOS to work properly. If a bug is found you can report it to me via the github.

# Documentation

An assortment of different colors
```
    class color
```

Prints the current system time.
```py
    incantoos.nowtime()
```


```py
    class ids

    ids.fourdashfour()
        Gives you a 8 character ID Ex. ("944b-fq8d")

    ids.ranid(amount : int)
        Gives you a randomized id of the specified amount
        
```

```py
    class times

    times.nowtime()
        Prints the current system time
    times.utcnowtime()
        Prints the current system time in UTC
    times.nowtimemdyhms
        Prints now time orgainzed by Month/Day/Year | Hour/Minute/Second
            Ex. [M/D/Y H:D:Y]
    times.nowtimemdyhms
        same thing as non utc
```